pub struct CheckpointProxy<'p>(/* private fields */);Implementations
Sourceimpl<'p> CheckpointProxy<'p>
impl<'p> CheckpointProxy<'p>
Sourcepub async fn new<P>(conn: &Connection, path: P) -> Result<CheckpointProxy<'p>>
pub async fn new<P>(conn: &Connection, path: P) -> Result<CheckpointProxy<'p>>
Creates a new proxy with the given path, and the default destination.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
pub async fn devices(&self) -> ZResult<Vec<OwnedObjectPath>>
Sourcepub fn cached_devices(
&self,
) -> Result<Option<<ZResult<Vec<OwnedObjectPath>> as ResultAdapter>::Ok>, <ZResult<Vec<OwnedObjectPath>> as ResultAdapter>::Err>
pub fn cached_devices( &self, ) -> Result<Option<<ZResult<Vec<OwnedObjectPath>> as ResultAdapter>::Ok>, <ZResult<Vec<OwnedObjectPath>> as ResultAdapter>::Err>
Get the cached value of the Devices property, or None if the property is not cached.
Sourcepub async fn receive_devices_changed(
&self,
) -> PropertyStream<'p, <ZResult<Vec<OwnedObjectPath>> as ResultAdapter>::Ok>
pub async fn receive_devices_changed( &self, ) -> PropertyStream<'p, <ZResult<Vec<OwnedObjectPath>> as ResultAdapter>::Ok>
Create a stream for the Devices property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
pub async fn created(&self) -> ZResult<i64>
Sourcepub fn cached_created(
&self,
) -> Result<Option<<ZResult<i64> as ResultAdapter>::Ok>, <ZResult<i64> as ResultAdapter>::Err>
pub fn cached_created( &self, ) -> Result<Option<<ZResult<i64> as ResultAdapter>::Ok>, <ZResult<i64> as ResultAdapter>::Err>
Get the cached value of the Created property, or None if the property is not cached.
Sourcepub async fn receive_created_changed(
&self,
) -> PropertyStream<'p, <ZResult<i64> as ResultAdapter>::Ok>
pub async fn receive_created_changed( &self, ) -> PropertyStream<'p, <ZResult<i64> as ResultAdapter>::Ok>
Create a stream for the Created property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
pub async fn rollback_timeout(&self) -> ZResult<u32>
Sourcepub fn cached_rollback_timeout(
&self,
) -> Result<Option<<ZResult<u32> as ResultAdapter>::Ok>, <ZResult<u32> as ResultAdapter>::Err>
pub fn cached_rollback_timeout( &self, ) -> Result<Option<<ZResult<u32> as ResultAdapter>::Ok>, <ZResult<u32> as ResultAdapter>::Err>
Get the cached value of the RollbackTimeout property, or None if the property is not cached.
Sourcepub async fn receive_rollback_timeout_changed(
&self,
) -> PropertyStream<'p, <ZResult<u32> as ResultAdapter>::Ok>
pub async fn receive_rollback_timeout_changed( &self, ) -> PropertyStream<'p, <ZResult<u32> as ResultAdapter>::Ok>
Create a stream for the RollbackTimeout property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.