pub struct GenericProxy<'p>(/* private fields */);Implementations
Sourceimpl<'p> GenericProxy<'p>
impl<'p> GenericProxy<'p>
Sourcepub async fn new<P>(conn: &Connection, path: P) -> Result<GenericProxy<'p>>
pub async fn new<P>(conn: &Connection, path: P) -> Result<GenericProxy<'p>>
Creates a new proxy with the given path, and the default destination.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
pub async fn hw_address(&self) -> ZResult<String>
Sourcepub fn cached_hw_address(
&self,
) -> Result<Option<<ZResult<String> as ResultAdapter>::Ok>, <ZResult<String> as ResultAdapter>::Err>
pub fn cached_hw_address( &self, ) -> Result<Option<<ZResult<String> as ResultAdapter>::Ok>, <ZResult<String> as ResultAdapter>::Err>
Get the cached value of the HwAddress property, or None if the property is not cached.
Sourcepub async fn receive_hw_address_changed(
&self,
) -> PropertyStream<'p, <ZResult<String> as ResultAdapter>::Ok>
pub async fn receive_hw_address_changed( &self, ) -> PropertyStream<'p, <ZResult<String> as ResultAdapter>::Ok>
Create a stream for the HwAddress property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
pub async fn type_description(&self) -> ZResult<String>
Sourcepub fn cached_type_description(
&self,
) -> Result<Option<<ZResult<String> as ResultAdapter>::Ok>, <ZResult<String> as ResultAdapter>::Err>
pub fn cached_type_description( &self, ) -> Result<Option<<ZResult<String> as ResultAdapter>::Ok>, <ZResult<String> as ResultAdapter>::Err>
Get the cached value of the TypeDescription property, or None if the property is not cached.
Sourcepub async fn receive_type_description_changed(
&self,
) -> PropertyStream<'p, <ZResult<String> as ResultAdapter>::Ok>
pub async fn receive_type_description_changed( &self, ) -> PropertyStream<'p, <ZResult<String> as ResultAdapter>::Ok>
Create a stream for the TypeDescription property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.