pub struct MacsecProxyBlocking<'p>(/* private fields */);Implementations
Sourceimpl<'p> MacsecProxyBlocking<'p>
impl<'p> MacsecProxyBlocking<'p>
Sourcepub fn new<P>(conn: &Connection, path: P) -> Result<MacsecProxyBlocking<'p>>
pub fn new<P>(conn: &Connection, path: P) -> Result<MacsecProxyBlocking<'p>>
Creates a new proxy with the given path, and the default destination.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
pub fn parent(&self) -> ZResult<OwnedObjectPath>
Sourcepub fn cached_parent(
&self,
) -> Result<Option<<ZResult<OwnedObjectPath> as ResultAdapter>::Ok>, <ZResult<OwnedObjectPath> as ResultAdapter>::Err>
pub fn cached_parent( &self, ) -> Result<Option<<ZResult<OwnedObjectPath> as ResultAdapter>::Ok>, <ZResult<OwnedObjectPath> as ResultAdapter>::Err>
Get the cached value of the Parent property, or None if the property is not cached.
Sourcepub fn receive_parent_changed(
&self,
) -> PropertyIterator<'p, <ZResult<OwnedObjectPath> as ResultAdapter>::Ok>
pub fn receive_parent_changed( &self, ) -> PropertyIterator<'p, <ZResult<OwnedObjectPath> as ResultAdapter>::Ok>
Create a stream for the Parent property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn sci(&self) -> ZResult<u64>
Sourcepub fn cached_sci(
&self,
) -> Result<Option<<ZResult<u64> as ResultAdapter>::Ok>, <ZResult<u64> as ResultAdapter>::Err>
pub fn cached_sci( &self, ) -> Result<Option<<ZResult<u64> as ResultAdapter>::Ok>, <ZResult<u64> as ResultAdapter>::Err>
Get the cached value of the Sci property, or None if the property is not cached.
Sourcepub fn receive_sci_changed(
&self,
) -> PropertyIterator<'p, <ZResult<u64> as ResultAdapter>::Ok>
pub fn receive_sci_changed( &self, ) -> PropertyIterator<'p, <ZResult<u64> as ResultAdapter>::Ok>
Create a stream for the Sci property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn icv_length(&self) -> ZResult<u8>
Sourcepub fn cached_icv_length(
&self,
) -> Result<Option<<ZResult<u8> as ResultAdapter>::Ok>, <ZResult<u8> as ResultAdapter>::Err>
pub fn cached_icv_length( &self, ) -> Result<Option<<ZResult<u8> as ResultAdapter>::Ok>, <ZResult<u8> as ResultAdapter>::Err>
Get the cached value of the IcvLength property, or None if the property is not cached.
Sourcepub fn receive_icv_length_changed(
&self,
) -> PropertyIterator<'p, <ZResult<u8> as ResultAdapter>::Ok>
pub fn receive_icv_length_changed( &self, ) -> PropertyIterator<'p, <ZResult<u8> as ResultAdapter>::Ok>
Create a stream for the IcvLength property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn cipher_suite(&self) -> ZResult<u64>
Sourcepub fn cached_cipher_suite(
&self,
) -> Result<Option<<ZResult<u64> as ResultAdapter>::Ok>, <ZResult<u64> as ResultAdapter>::Err>
pub fn cached_cipher_suite( &self, ) -> Result<Option<<ZResult<u64> as ResultAdapter>::Ok>, <ZResult<u64> as ResultAdapter>::Err>
Get the cached value of the CipherSuite property, or None if the property is not cached.
Sourcepub fn receive_cipher_suite_changed(
&self,
) -> PropertyIterator<'p, <ZResult<u64> as ResultAdapter>::Ok>
pub fn receive_cipher_suite_changed( &self, ) -> PropertyIterator<'p, <ZResult<u64> as ResultAdapter>::Ok>
Create a stream for the CipherSuite property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn window(&self) -> ZResult<u32>
Sourcepub fn cached_window(
&self,
) -> Result<Option<<ZResult<u32> as ResultAdapter>::Ok>, <ZResult<u32> as ResultAdapter>::Err>
pub fn cached_window( &self, ) -> Result<Option<<ZResult<u32> as ResultAdapter>::Ok>, <ZResult<u32> as ResultAdapter>::Err>
Get the cached value of the Window property, or None if the property is not cached.
Sourcepub fn receive_window_changed(
&self,
) -> PropertyIterator<'p, <ZResult<u32> as ResultAdapter>::Ok>
pub fn receive_window_changed( &self, ) -> PropertyIterator<'p, <ZResult<u32> as ResultAdapter>::Ok>
Create a stream for the Window property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn encoding_sa(&self) -> ZResult<u8>
Sourcepub fn cached_encoding_sa(
&self,
) -> Result<Option<<ZResult<u8> as ResultAdapter>::Ok>, <ZResult<u8> as ResultAdapter>::Err>
pub fn cached_encoding_sa( &self, ) -> Result<Option<<ZResult<u8> as ResultAdapter>::Ok>, <ZResult<u8> as ResultAdapter>::Err>
Get the cached value of the EncodingSa property, or None if the property is not cached.
Sourcepub fn receive_encoding_sa_changed(
&self,
) -> PropertyIterator<'p, <ZResult<u8> as ResultAdapter>::Ok>
pub fn receive_encoding_sa_changed( &self, ) -> PropertyIterator<'p, <ZResult<u8> as ResultAdapter>::Ok>
Create a stream for the EncodingSa property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn validation(&self) -> ZResult<String>
Sourcepub fn cached_validation(
&self,
) -> Result<Option<<ZResult<String> as ResultAdapter>::Ok>, <ZResult<String> as ResultAdapter>::Err>
pub fn cached_validation( &self, ) -> Result<Option<<ZResult<String> as ResultAdapter>::Ok>, <ZResult<String> as ResultAdapter>::Err>
Get the cached value of the Validation property, or None if the property is not cached.
Sourcepub fn receive_validation_changed(
&self,
) -> PropertyIterator<'p, <ZResult<String> as ResultAdapter>::Ok>
pub fn receive_validation_changed( &self, ) -> PropertyIterator<'p, <ZResult<String> as ResultAdapter>::Ok>
Create a stream for the Validation property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn encrypt(&self) -> ZResult<bool>
Sourcepub fn cached_encrypt(
&self,
) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
pub fn cached_encrypt( &self, ) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
Get the cached value of the Encrypt property, or None if the property is not cached.
Sourcepub fn receive_encrypt_changed(
&self,
) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
pub fn receive_encrypt_changed( &self, ) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
Create a stream for the Encrypt property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn protect(&self) -> ZResult<bool>
Sourcepub fn cached_protect(
&self,
) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
pub fn cached_protect( &self, ) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
Get the cached value of the Protect property, or None if the property is not cached.
Sourcepub fn receive_protect_changed(
&self,
) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
pub fn receive_protect_changed( &self, ) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
Create a stream for the Protect property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn include_sci(&self) -> ZResult<bool>
Sourcepub fn cached_include_sci(
&self,
) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
pub fn cached_include_sci( &self, ) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
Get the cached value of the IncludeSci property, or None if the property is not cached.
Sourcepub fn receive_include_sci_changed(
&self,
) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
pub fn receive_include_sci_changed( &self, ) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
Create a stream for the IncludeSci property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn es(&self) -> ZResult<bool>
Sourcepub fn cached_es(
&self,
) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
pub fn cached_es( &self, ) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
Get the cached value of the Es property, or None if the property is not cached.
Sourcepub fn receive_es_changed(
&self,
) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
pub fn receive_es_changed( &self, ) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
Create a stream for the Es property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn scb(&self) -> ZResult<bool>
Sourcepub fn cached_scb(
&self,
) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
pub fn cached_scb( &self, ) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
Get the cached value of the Scb property, or None if the property is not cached.
Sourcepub fn receive_scb_changed(
&self,
) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
pub fn receive_scb_changed( &self, ) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
Create a stream for the Scb property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn replay_protect(&self) -> ZResult<bool>
Sourcepub fn cached_replay_protect(
&self,
) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
pub fn cached_replay_protect( &self, ) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
Get the cached value of the ReplayProtect property, or None if the property is not cached.
Sourcepub fn receive_replay_protect_changed(
&self,
) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
pub fn receive_replay_protect_changed( &self, ) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
Create a stream for the ReplayProtect property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.