pub struct WiredProxyBlocking<'p>(/* private fields */);Implementations
Sourceimpl<'p> WiredProxyBlocking<'p>
impl<'p> WiredProxyBlocking<'p>
Sourcepub fn new<P>(conn: &Connection, path: P) -> Result<WiredProxyBlocking<'p>>
pub fn new<P>(conn: &Connection, path: P) -> Result<WiredProxyBlocking<'p>>
Creates a new proxy with the given path, and the default destination.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
pub fn hw_address(&self) -> ZResult<String>
Sourcepub fn cached_hw_address(
&self,
) -> Result<Option<<ZResult<String> as ResultAdapter>::Ok>, <ZResult<String> as ResultAdapter>::Err>
pub fn cached_hw_address( &self, ) -> Result<Option<<ZResult<String> as ResultAdapter>::Ok>, <ZResult<String> as ResultAdapter>::Err>
Get the cached value of the HwAddress property, or None if the property is not cached.
Sourcepub fn receive_hw_address_changed(
&self,
) -> PropertyIterator<'p, <ZResult<String> as ResultAdapter>::Ok>
pub fn receive_hw_address_changed( &self, ) -> PropertyIterator<'p, <ZResult<String> as ResultAdapter>::Ok>
Create a stream for the HwAddress property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn perm_hw_address(&self) -> ZResult<String>
Sourcepub fn cached_perm_hw_address(
&self,
) -> Result<Option<<ZResult<String> as ResultAdapter>::Ok>, <ZResult<String> as ResultAdapter>::Err>
pub fn cached_perm_hw_address( &self, ) -> Result<Option<<ZResult<String> as ResultAdapter>::Ok>, <ZResult<String> as ResultAdapter>::Err>
Get the cached value of the PermHwAddress property, or None if the property is not cached.
Sourcepub fn receive_perm_hw_address_changed(
&self,
) -> PropertyIterator<'p, <ZResult<String> as ResultAdapter>::Ok>
pub fn receive_perm_hw_address_changed( &self, ) -> PropertyIterator<'p, <ZResult<String> as ResultAdapter>::Ok>
Create a stream for the PermHwAddress property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn speed(&self) -> ZResult<u32>
Sourcepub fn cached_speed(
&self,
) -> Result<Option<<ZResult<u32> as ResultAdapter>::Ok>, <ZResult<u32> as ResultAdapter>::Err>
pub fn cached_speed( &self, ) -> Result<Option<<ZResult<u32> as ResultAdapter>::Ok>, <ZResult<u32> as ResultAdapter>::Err>
Get the cached value of the Speed property, or None if the property is not cached.
Sourcepub fn receive_speed_changed(
&self,
) -> PropertyIterator<'p, <ZResult<u32> as ResultAdapter>::Ok>
pub fn receive_speed_changed( &self, ) -> PropertyIterator<'p, <ZResult<u32> as ResultAdapter>::Ok>
Create a stream for the Speed property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn s390_subchannels(&self) -> ZResult<Vec<String>>
Sourcepub fn cached_s390_subchannels(
&self,
) -> Result<Option<<ZResult<Vec<String>> as ResultAdapter>::Ok>, <ZResult<Vec<String>> as ResultAdapter>::Err>
pub fn cached_s390_subchannels( &self, ) -> Result<Option<<ZResult<Vec<String>> as ResultAdapter>::Ok>, <ZResult<Vec<String>> as ResultAdapter>::Err>
Get the cached value of the S390Subchannels property, or None if the property is not cached.
Sourcepub fn receive_s390_subchannels_changed(
&self,
) -> PropertyIterator<'p, <ZResult<Vec<String>> as ResultAdapter>::Ok>
pub fn receive_s390_subchannels_changed( &self, ) -> PropertyIterator<'p, <ZResult<Vec<String>> as ResultAdapter>::Ok>
Create a stream for the S390Subchannels property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
pub fn carrier(&self) -> ZResult<bool>
Sourcepub fn cached_carrier(
&self,
) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
pub fn cached_carrier( &self, ) -> Result<Option<<ZResult<bool> as ResultAdapter>::Ok>, <ZResult<bool> as ResultAdapter>::Err>
Get the cached value of the Carrier property, or None if the property is not cached.
Sourcepub fn receive_carrier_changed(
&self,
) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
pub fn receive_carrier_changed( &self, ) -> PropertyIterator<'p, <ZResult<bool> as ResultAdapter>::Ok>
Create a stream for the Carrier property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.